durtools.assignable_rational_to_lilypond_duration_string
========================================================

.. autofunction:: abjad.tools.durtools.assignable_rational_to_lilypond_duration_string
